@@ -12,6 +12,7 @@ from importlib import import_module
 
 from distutils.errors import DistutilsOptionError, DistutilsFileError
 from packaging.version import LegacyVersion, parse
+from packaging.specifiers import SpecifierSet
 from six import string_types, PY3
 
 
@@ -554,6 +555,7 @@ class ConfigOptionsHandler(ConfigHandler):
             'packages': self._parse_packages,
             'entry_points': self._parse_file,
             'py_modules': parse_list,
+            'python_requires': SpecifierSet,
         }
 
     def _parse_packages(self, value):
